Indonesia expands search for missing AirAsia jet, U.S. sends warship | Reuters
Author: By Fergus Jensen
Description: JAKARTA (Reuters) - Countries around Asia on Tuesday stepped up the search for an AirAsia plane carrying 162 people that is presumed to have crashed in shallow waters off the Indonesian coast, with Washington
Keywords: Darren Whiteside

- Edition:
  IN
  - Africa
  - Arabic
  - Argentina
  - Brazil
  - Canada
  - China
  - France
  - Germany
  - Italy
  - Japan
  - Latin America
  - Mexico
  - Russia
  - Spain
  - United Kingdom
  - United States

- Article
- Comments (0)
- Slideshow
- Video

# Indonesia expands search for missing AirAsia jet, U.S. sends warship

By Fergus Jensen

JAKARTA Tue Dec 30, 2014 9:21am IST

- Tweet
- Link this
- Share this
- By Fergus Jensen JAKARTA (Reuters) - Countries around Asia on Tuesday stepped up the search for an AirAsia plane carrying 162 people that is presumed to have crashed in shallow waters off the Indonesian coast, with Washington also sending a warship...
- Email
- Print

1 of 4. Authorities monitor progress in the search for AirAsia Flight QZ8501 in the Mission Control Center inside the National Search and Rescue Agency in Jakarta December 29, 2014.

Credit: Reuters/Darren Whiteside

### Related Video

## Families turn to prayer for missing AirAsia flight

Mon, Dec 29 2014

## Pope Francis prays for AirAsia missing plane, Greece ferry disaster

Sun, Dec 28 2014

### Related Topics

- Top News »
- World »

### Stocks

### India in 2014: Year in Review

## Bollywood 2014

The best and worst of Bollywood in 2014. Full Article

- A dream run for markets
- Year of leagues for sports
- Best photos of the year 2014
- Top pictures of the year: India
- Full coverage: India in 2014

JAKARTA (Reuters) - Countries around Asia on Tuesday stepped up the search for an AirAsia plane carrying 162 people that is presumed to have crashed in shallow waters off the Indonesian coast, with Washington also sending a warship to help find the missing jet.

Soelistyo, head of Indonesia's search and rescue agency, told local television the search area between the islands of Sumatra and Borneo would be expanded. Authorities would also begin scouring nearby islands as well as coastal land on Indonesia's side of Borneo.

So far the focus of the search has been the Java Sea.

There have been no confirmed signs of wreckage from the Airbus A320-200 operated by Indonesia AirAsia, which disappeared in poor weather on Sunday morning during a flight from the Indonesian city of Surabaya to Singapore.

The missing plane, which was carrying mainly Indonesians, could be at the bottom of the sea, Soelistyo said on Monday.

The Java Sea is relatively shallow, making it easier to spot wreckage in the water, say oceanographers, but strong currents and winds in the area mean any debris would be drifting up to 50 km (31 miles) a day east, away from the impact zone.

"The lesson that should be learned from MH370 is that you need to move quickly," said Charitha Pattiaratchi, an oceanographer at the University of Western Australia, referring to the Malaysia Airlines flight that went missing on March 8 during a trip from Kuala Lumpur to Beijing with 239 passengers and crew and which has not been found.

Around 30 ships and 21 aircraft from Indonesia, Australia, Malaysia, Singapore and South Korea would search up to 10,000 square nautical miles on Tuesday, officials said.

Indonesian Air Force spokesman Hadi Tjahjanto said authorities would investigate an oil spill sighted on Monday, although a separate possible slick turned out to be a reef.

Searchers had investigated several areas where possible debris had been sighted in the water but had found nothing connected to the missing plane, Tjahjanto told Reuters.

Authorities would also investigate reports by local fishermen of an explosion on Sunday morning off an island in the area, Tjahjanto added, although dynamite fishing is common in Indonesian waters.

The U.S. military said the USS Sampson, a guided missile destroyer, would be on the scene later on Tuesday.

"We stand ready to assist in any way possible," Pentagon spokesman Mark Wright said.

COULD PLANE HAVE STALLED?

What happened to Flight QZ8501, which had sought permission from Indonesian air traffic control to ascend to avoid clouds, is still a mystery.

Online discussions among pilots have centred on unconfirmed secondary radar data from Malaysia that suggested the aircraft was climbing at a speed of 353 knots, about 100 knots too slow in poor weather, and that it might have stalled.

While searchers had picked up an emergency locator signal off the south of Borneo, no subsequent signal was found, officials said.

The plane, whose engines were made by CFM International, co-owned by General Electric and Safran of France, lacked real-time engine diagnostics or monitoring, a GE spokesman said. Such systems are mainly used on long-haul flights and can provide clues to airlines and investigators when things go wrong.

Officials said the sea in the general search area was only 50 to 100 (150 to 300 feet) metres deep, which would be a help in finding the plane.

"The Java Sea area where they are now searching isn't even an ocean, it's more of an inland sea," Erik van Sebille, a physical oceanographer at the University of New South Wales in Sydney told Reuters.

"It's so shallow that they may just be able to spot the plane," said van Sebille, noting that sunlight travels through water up to about 100 metres.

Oceanographer Pattiaratchi said debris would normally be expected to float on the surface for around 18 days before sinking.

Three airline disasters involving Malaysian-affiliated carriers in less than a year have dented confidence in the country's aviation industry and spooked air travellers across the region.

In the third incident, Malaysia Airlines Flight MH17 was shot down over Ukraine on July 17, killing all 298 people on board.

NO FOUL PLAY SEEN

On board Flight QZ8501 were 155 Indonesians, three South Koreans, and one person each from Singapore, Malaysia and Britain. The co-pilot was French.

U.S. law enforcement and security officials said passenger and crew lists were being closely examined but so far nothing significant had turned up and that the incident was still regarded as an unexplained accident.

The plane, which did not issue a distress signal, disappeared after its pilot failed to get permission to fly higher because of heavy air traffic, officials said.

Pilots and aviation experts said thunderstorms, and requests to gain altitude to avoid them, were not unusual in that area.

The Indonesian pilot was experienced and the plane last underwent maintenance in mid-November, the airline said.

Indonesia AirAsia is 49 percent owned by Malaysia-based budget carrier AirAsia.

The AirAsia group, including affiliates in Thailand, the Philippines and India, had not suffered a crash since its Malaysian budget operations began in 2002.

The plane's disappearance comes at a sensitive time for Jakarta's aviation authorities, as they strive to improve the country's safety reputation to match its status as one of the airline industry's fastest growing markets.

(Additional reporting by Wilda Asmarini, Fransiska Nangoy, Cindy Silviana, Kanupriya Kapoor, Michael Taylor, Nilufar Rizki and Siva Govindasamy in JAKARTA, Al-Zaquan Amer Hamzah and Praveen Menon in KUALA LUMPUR, Saeed Azhar, Rujun Shen and Anshuman Daga in SINGAPORE, Jane Wardell in SYDNEY, Ben Blanchard in BEIJING, Tim Hepher in PARIS and Mark Hosenball, David Brunnstrom and Lesley Wroughton in WASHINGTON; Writing by Dean Yates; Editing by Michael Perry)

FILED UNDER:
Top News
World

- Tweet this
- Link this
- Share this
- Digg this
- Email
- Print
- Reprints

### Trending On Reuters

### Banking

## India needs reforms in banking sector, more autonomy for state banks: Jaitley

India needs to "conceive" several reforms in the banking sector, Finance Minister Arun Jaitley told reporters on the sidelines of a two-day banking retreat. Full Article

- India prepares reform plan for ailing state banks

### Follow Reuters

- Facebook
- Twitter
- RSS
- YouTube

### REUTERS SHOWCASE

## Factory Activity

Weak factory reports from Asia, Europe suggest more central bank action Full Article

## AirAsia Jet Crash

Search teams battle rough weather in hunt for AirAsia wreck Full Article

## Banking Sector

India prepares reform roadmap for ailing state banks Full Article

## Solar Energy

Govt raises solar investment target to $100 bln by 2022 Full Article

## India Factory Growth

Dec factory growth at 2-year high as orders surge - PMI Full Article

## Tata Steel Mine

Tata Steel resumes operations at top iron ore mine - spokesman Full Article

## U.S. Economy

U.S. factory sector suffers end-of-year chill Full Article

## Trip Tips

A glimpse of little Tibet in southern India Full Article

## India in 2014

A review of the top stories from India Full Coverage

## Reuters India Mobile

Get the latest news on the go. Visit Reuters India on your mobile device Full Coverage

- Edition:
  IN
  - Arabic
  - Argentina
  - Brazil
  - Canada
  - China
  - France
  - Germany
  - Italy
  - Japan
  - Latin America
  - Mexico
  - Russia
  - Spain
  - United Kingdom
  - United States

Back to top

Reuters.com

- Business
- Markets
- India
- Technology
- Opinion
- Money
- Pictures
- Videos
- Site Index
- Mobile

More from Reuters

- Reuters News Agency
- Brand Attribution Guidelines
- Delivery Options

Support & Contact

- Support
- Corrections

Connect with Reuters

- Twitter
- Facebook
- LinkedIn
- RSS
- Newsletters

About

- Privacy Policy
- Terms of Use
- AdChoices
- Copyright

Our Flagship financial information platform incorporating Reuters Insider
An ultra-low latency infrastructure for electronic trading and data distribution
A connected approach to governance, risk and compliance
Our next generation legal research platform
Our global tax workstation

- Thomsonreuters.com
- About Thomson Reuters
- Investor Relations
- Careers
- Contact Us

Thomson Reuters is the world's largest international multimedia news agency, providing investing news, world news, business news, technology news, headline news, small business news, news alerts, personal finance, stock market, and mutual funds information available on Reuters.com, video, mobile, and interactive television platforms. Thomson Reuters journalists are subject to an Editorial Handbook which requires fair presentation and disclosure of relevant interests.

NYSE and AMEX quotes delayed by at least 20 minutes. Nasdaq delayed by at least 15 minutes. For a complete list of exchanges and delays, please click here.